==> dl.php?src=linea21_2_3_0.zip: linea21/project/menurub.php <==
<?php
/**
 * Project module
 * 
 * Set-up module related menu in back-office
 * 
 * @package linea21\modules\project
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('project')) ReloadIndex('admin');
////////////

$rub_link_add=$rub_link."&amp;todo=add";
$rub_link_list=$rub_link."&amp;todo=list";
$rub_link_mod=$rub_link."&amp;todo=mod";
$rub_link_det=$rub_link."&amp;todo=det";
$rub_link_report=$rub_link."&amp;todo=report";

$search="search.php?rub=".$rub;
if($todo=='add') $title=_t('project','add');
if($todo=='list') $title=_t('project','list');
if($todo=='mod') $title=_t('project','mod');
if($todo=='sup') $title=_t('project','sup');
if($todo=='det') $title=_t('project','det');
?>
<div id="itemenu">
	<h1><?php echo $title; ?></h1>
	<div class="contentlink">
		<?php $dispatcher->notify(new sfEvent('secondary_menu', 'admin_project.menu_start'));?>
		<?php if ($l21auth->isSuperAdmin()) { ?>
		<a	href="<?php echo $rub_link_report; ?>" title="<?php echo _t('export','action');?>"><i class="icon-export"></i><?php echo _t('export','action');?></a>
		<a href="<?php echo $rub_link_add; ?>" title="<?php echo _t('project','add');?>"><i class="icon-plus"></i><?php echo _t('project','add');?></a>
		<?php } ?>
		<a href="<?php echo $rub_link_list; ?>" title="<?php echo _t('project','list');?>"><i class="icon-list"></i><?php echo _t('project','list');?></a>
		<a href="<?php echo $search; ?>" title="<?php echo _t('menu','search');?>"><i class="icon-search"></i><?php echo _t('menu','search');?></a>
		<?php $dispatcher->notify(new sfEvent('secondary_menu', 'admin_project.menu_end'));?>
	</div>
</div>

==> dl.php?src=linea21_2_7_0.zip: linea21/project/menurub.php <==
<?php
/**
 * Project module
 * 
 * Set-up module related menu in back-office
 * 
 * @package linea21\modules\project
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('project')) ReloadIndex('admin');
////////////

$rub_link_add=$rub_link."&amp;todo=add";
$rub_link_list=$rub_link."&amp;todo=list";
$rub_link_mod=$rub_link."&amp;todo=mod";
$rub_link_det=$rub_link."&amp;todo=det";
$rub_link_report=$rub_link."&amp;todo=report";

$search="search.php?rub=".$rub;
if($todo=='add') $title=_t('project','add');
if($todo=='list') $title=_t('project','list');
if($todo=='mod') $title=_t('project','mod');
if($todo=='sup') $title=_t('project','sup');
if($todo=='det') $title=_t('project','det');
?>
<div id="itemenu">
	<h1><?php echo $title; ?></h1>
	<div class="contentlink">
		<?php $dispatcher->notify(new sfEvent('secondary_menu', 'admin_project.menu_start'));?>
		<?php if ($l21auth->isSuperAdmin()) { ?>
		<a	href="<?php echo $rub_link_report; ?>" title="<?php echo _t('export','action');?>" class="export-link"><?php echo _t('export','action');?></a>
		<a href="<?php echo $rub_link_add; ?>" title="<?php echo _t('project','add');?>" class="add-link"><?php echo _t('project','add');?></a>
		<?php } ?>
		<a href="<?php echo $rub_link_list; ?>" title="<?php echo _t('project','list');?>" class="list-link"><?php echo _t('project','list');?></a>
		<a href="<?php echo $search; ?>" title="<?php echo _t('menu','search');?>" class="search-link"><?php echo _t('menu','search');?></a>
		<?php $dispatcher->notify(new sfEvent('secondary_menu', 'admin_project.menu_end'));?>
	</div>
</div>
